summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/oscaraccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/oscaraccount.h')
-rw-r--r--kopete/protocols/oscar/oscaraccount.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kopete/protocols/oscar/oscaraccount.h b/kopete/protocols/oscar/oscaraccount.h
index 9998bed8..bccaa9a1 100644
--- a/kopete/protocols/oscar/oscaraccount.h
+++ b/kopete/protocols/oscar/oscaraccount.h
@@ -42,9 +42,10 @@ class TQTextCodec;
class KDE_EXPORT OscarAccount : public Kopete::PasswordedAccount
{
Q_OBJECT
+ TQ_OBJECT
public:
- OscarAccount(Kopete::Protocol *parent, const TQString &accountID, const char *name=0L, bool isICQ=false);
+ OscarAccount(Kopete::Protocol *tqparent, const TQString &accountID, const char *name=0L, bool isICQ=false);
virtual ~OscarAccount();
/** Provide the derived accounts and contacts with access to the backend */
@@ -67,7 +68,7 @@ public:
/**
* Sets the account away
*/
- virtual void setAway( bool away, const TQString &awayMessage = TQString::null ) = 0;
+ virtual void setAway( bool away, const TQString &awayMessage = TQString() ) = 0;
/**
* Accessor method for the action menu
@@ -133,16 +134,16 @@ protected:
* Adds a contact to a meta contact
*/
virtual bool createContact(const TQString &contactId,
- Kopete::MetaContact *parentContact );
+ Kopete::MetaContact *tqparentContact );
/**
* Protocols using Oscar must implement this to perform the instantiation
* of their contact for Kopete. Called by @ref createContact().
* @param contactId theprotocol unique id of the contact
* @param parentContact the parent metacontact
* @return whether the creation succeeded or not
*/
- virtual OscarContact *createNewContact( const TQString &contactId, Kopete::MetaContact *parentContact, const SSI& ssiItem ) = 0;
+ virtual OscarContact *createNewContact( const TQString &contactId, Kopete::MetaContact *tqparentContact, const SSI& ssiItem ) = 0;
virtual TQString sanitizedMessage( const TQString& message ) = 0;
@@ -133,16 +134,16 @@ protected:
* of their contact for Kopete. Called by @ref createContact().
* @param contactId theprotocol unique id of the contact
- * @param parentContact the parent metacontact
+ * @param tqparentContact the tqparent metacontact
* @return whether the creation succeeded or not
*/